/**
 * PETALS: PETALS Services Platform
 * Copyright (C) 2005 EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): Adrien LOUIS
 * --------------------------------------------------------------------------
 * $Id: InstallationContextImpl.java,v 1.3 2005/07/22 10:24:27 alouis Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.petals.jbi.component.context;

import java.util.List;

import javax.jbi.component.ComponentContext;
import javax.jbi.component.InstallationContext;

import org.ow2.petals.jbi.descriptor.ComponentDescription;
import org.ow2.petals.jbi.descriptor.Extensions;
import org.w3c.dom.DocumentFragment;

/**
 * @version $Rev: 250 $ $Date: 2006-04-21 14:20:57 +0200 (ven, 21 avr 2006) $
 * @since Petals 1.0
 * @author wjoseph - EBM Webousourcing
 *
 */
public class InstallationContextImpl implements InstallationContext {

    private List classPathElements;

    private String componentClassName;

    private String componentName;

    private ComponentContext context;

    private boolean install;

    private DocumentFragment installationDescriptorExtension;

    private String installRoot;

    public InstallationContextImpl(ComponentDescription component,
            ComponentContext context, boolean install) {
        super();

        this.context = new ComponentContextForInstallation(context);
        this.componentClassName = component.getComponentClassName();
        this.componentName = component.getIdentification().getName();
        this.install = install;
        this.classPathElements = component.getComponentClassPath();
        this.installRoot = context.getInstallRoot();
        final Extensions extensions = component.getExtensions();
        this.installationDescriptorExtension = (extensions == null ? null
                : extensions.getDocumentFragment());
    }

    /*
     * (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#getClassPathElements()
     */
    public List getClassPathElements() {
        return classPathElements;
    }

    /*
     * (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#getComponentClassName()
     */
    public String getComponentClassName() {
        return componentClassName;
    }

    /*
     * (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#getComponentName()
     */
    public String getComponentName() {
        return componentName;
    }

    /*
     * Return a <code>ComponentContextForInstallation</code> wrapper of the
     * Componentcontext (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#getContext()
     */
    public ComponentContext getContext() {
        return context;
    }

    /*
     * (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#getInstallationDescriptorExtension()
     */
    public DocumentFragment getInstallationDescriptorExtension() {
        return installationDescriptorExtension;
    }

    /*
     * (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#getInstallRoot()
     */
    public String getInstallRoot() {
        return installRoot;
    }

    /*
     * (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#isInstall()
     */
    public boolean isInstall() {
        return install;
    }

    /*
     * TODO must redefine the classpath at the execution time
     *
     * (non-Javadoc)
     *
     * @see javax.jbi.component.InstallationContext#setClassPathElements(java.util.List)
     */
    public void setClassPathElements(List classPathElements) {
        if (classPathElements == null) {
            throw new IllegalArgumentException(
                    "classPathElements must not be null");
        }
        if (classPathElements.isEmpty()) {
            throw new IllegalArgumentException(
                    "classPathElements must not be empty");
        }
        this.classPathElements = classPathElements;
    }

	public void setInstall(boolean install) {
		this.install = install;
	}

}
