/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.jbi.management.task;

import java.io.File;
import java.util.HashMap;

import org.objectweb.petals.PetalsException;
import org.ow2.petals.jbi.descriptor.JBIDescriptor;
import org.objectweb.petals.jbi.management.util.PackageHandler;
import org.objectweb.petals.processor.Task;
import org.objectweb.petals.util.LoggingUtil;

/**
 * This task checks the validity of a package to install. <br/> Inputs : unzipped package root
 * {@link File} <br/> Outputs : Entity name
 * (String), {@link JBIDescriptor} <br/>
 * 
 * @author ofabre
 * 
 */
public abstract class AbstractCheckPackageTask implements Task {

    /**
     * logger wrapper
     */
    protected LoggingUtil log;

    private PackageHandler packageHandler;

    public AbstractCheckPackageTask(LoggingUtil log,
        PackageHandler packageHandler) {
        super();
        this.log = log;
        this.packageHandler = packageHandler;
    }

    @SuppressWarnings("unchecked")
    public void execute(HashMap context) throws Exception {

        File packageFile = (File) context.get(TaskContextConstants.UNZIP_ROOT);

        /*
         * Load descriptor
         */
        JBIDescriptor descriptor = packageHandler.loadDescriptor(packageFile);

        /*
         * Check the entity package
         */
        checkPackage(descriptor, packageFile);

        /*
         * Extract entity unique identifier
         */
        context.put(TaskContextConstants.DESCRIPTOR, descriptor);
        context.put(TaskContextConstants.ENTITY_NAME,
            extractEntityName(descriptor));

    }

    protected abstract String extractEntityName(JBIDescriptor descriptor);

    protected abstract void checkPackage(JBIDescriptor descriptor,
        File packageFile) throws PetalsException;

    public void undo(HashMap context) throws Exception {
        // Nothing to do

    }

}
