/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.jbi.management.task.installation.install.component;

import java.io.File;

import org.objectweb.petals.PetalsException;
import org.objectweb.petals.util.StringHelper;
import org.ow2.petals.jbi.descriptor.ComponentDescription;
import org.ow2.petals.jbi.descriptor.JBIDescriptor;
import org.objectweb.petals.jbi.management.admin.AdminServiceMBean;
import org.objectweb.petals.jbi.management.task.AbstractCheckPackageTask;
import org.objectweb.petals.jbi.management.task.installation.InstallationUtils;
import org.objectweb.petals.jbi.management.util.PackageHandler;
import org.objectweb.petals.util.LoggingUtil;

/**
 * This task checks the validity of the component package.
 * 
 * @author ofabre - EBM Websourcing
 * 
 */
public class ComponentCheckPackageTask extends AbstractCheckPackageTask {

    protected AdminServiceMBean adminService;

    public ComponentCheckPackageTask(LoggingUtil log,
        PackageHandler packageHandler, AdminServiceMBean adminService) {
        super(log, packageHandler);
        this.adminService = adminService;
    }

    /**
     * Check the validity of the component archive
     * 
     * @param descriptor
     *            the component <code>JBIDescriptor</code>
     * @param filePackage
     *            the service assembly package root
     * @return true if checking is completly ok and false otherwise
     * @throws PetalsException
     *             if component element or name is null or empty, if component
     *             is already installed or if some classpath elements of the
     *             component are missing
     */
    protected void checkPackage(JBIDescriptor descriptor, File filePackage)
        throws PetalsException {
        String msg = null;

        /*
         * check if jbi descriptor has a component element
         */

        ComponentDescription comp = descriptor.getComponent();
        if (comp == null) {
            msg = "The component production element was not found in "
                + "JBI Descriptor within installation package: "
                + filePackage.getAbsolutePath();
            log.error(msg);
            throw new PetalsException(msg);
        } else {

            /*
             * check if it is already loaded by package uuid
             */

            String compName = comp.getIdentification().getName();

            if (StringHelper.isNullOrEmpty(compName)) {
                msg = "The component name must be non null and non empty for the new component :"
                    + filePackage.getAbsolutePath();
                log.error(msg);
                throw new PetalsException(msg);
            }

            if (isComponentLoaded(compName)) {
                msg = "Other installation package already exists loaded in "
                    + "the component framework: " + compName;

                log.error(msg);
                throw new PetalsException(msg);
            } else {

                /*
                 * Check the classpath elements of the component
                 */
                InstallationUtils.checkClassPathElements(filePackage, comp
                    .getBootstrapClassPath());
                InstallationUtils.checkClassPathElements(filePackage, comp
                    .getComponentClassPath());

            }
        }
    }

    private boolean isComponentLoaded(String componentName) {
        return adminService.getInstallerByName(componentName) != null;
    }

    @Override
    protected String extractEntityName(JBIDescriptor descriptor) {
        return descriptor.getComponent().getIdentification().getName();
    }

}
