package org.objectweb.petals.jbi.messaging.registry;

import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

public interface EndpointCacheService {
	
	/**
	 * Put a service endpoint list satisfaying a service in the cache.
	 * 
	 * @param serviceName
	 *            Service name
	 * @param endpoints
	 *            Service endpoints satisfaying the service
	 *            <code>serviceName</code>.
	 */
	public void putServiceEndpoints(final QName serviceName, final ServiceEndpoint[] endpoints);
	
	/**
	 * Get a service endpoint list satisfaying a service from the cache.
	 * 
	 * @param serviceName
	 *            Service name
	 * @return A service endpoints list satisfaying the service
	 *         <code>serviceName</code>, or <code>null</code> if not previously
	 *         cached.
	 */
	public ServiceEndpoint[] getServiceEndpoints(final QName serviceName);
	
	/**
	 * Put a service endpoint list satisfaying an interface in the cache.
	 * 
	 * @param itfName
	 *            Interface name
	 * @param endpoints
	 *            Service endpoints satisfaying the interface
	 *            <code>itfName</code>.
	 */
	public void putInterfaceEndpoints(final QName itfName, final ServiceEndpoint[] endpoints);
	
	/**
	 * Get a service endpoint list satisfaying a service from the cache.
	 * 
	 * @param itfName
	 *            Interface name
	 * @return A service endpoints list satisfaying the interface
	 *         <code>itfName</code>, or <code>null</code> if not previously
	 *         cached.
	 */
	public ServiceEndpoint[] getInterfaceEndpoints(final QName itfName);
	
	/**
	 * Clear the cache.
	 */
	public void clear();

}
