/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2009 OW2, http://www.ow2.org/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: $
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.extensions.transporter.nio;

/**
 * 
 * NIO Transporter parameters name and default values
 * 
 * @author Christophe DENEUX (Capgemini Sud)
 * 
 */
public class Parameters {
	
	/*
	 * PEtALS NIO Transporter parameters
	 */

	/**
	 * The default maximum size of the blocking queue containing message exchanges that
	 * wait, into the transported, to be processed by component.
	 */
	public static final int DEFAULT_QUEUE_SIZE = 10000;
	
	/*
	 * NIO Server parameters
	 */

	/**
	 * The default listen port (7780) of the NIO transporter
	 */
	public static final String DEFAULT_LISTEN_PORT = "7780";

	/**
	 * Name of the parameter that defines the listen port of the NIO
	 * transporter.
	 */
	public static final String PROP_NAME_LISTEN_PORT = "transporter.nio.server.port";
	
	/**
	 * The default number (4) of threads used to deserialized incoming bytes
	 * into {@link Object}.
	 */
	public static final String DEFAULT_ACCEPTORS = "4";

	/**
	 * Name of the parameter that defines the number of threads used to
	 * deserialized incoming bytes into {@link Object}.
	 */
	public static final String PROP_NAME_ACCEPTORS = "transporter.nio.server.acceptors";

	/*
	 * NIO Client parameters
	 */

	/**
	 * The default connection timeout (5000ms) of the NIO transporter.
	 */
	public static final String DEFAULT_CONNECTION_TIMEOUT = "5000";

	/**
	 * Name of the parameter that defines the connection timeout in
	 * milli-seconds of the NIO transporter.
	 */
	public static final String PROP_NAME_CONNECTION_TIMEOUT = "transporter.nio.client.connection-timeout";
	
	/**
	 * The default send timeout (5000ms) of the NIO transporter.
	 */
	public static final String DEFAULT_SEND_TIMEOUT = "5000";

	/**
	 * Name of the parameter that defines the send timeout in
	 * milli-seconds of the NIO transporter.
	 */
	public static final String PROP_NAME_SEND_TIMEOUT = "transporter.nio.client.send-timeout";
	
	/**
	 * The default maximum number (8) of objects (per target container) that can
	 * be borrowed from the pool at one time.
	 */
	public static final String DEFAULT_MAX_ACTIVE = "8";

	/**
	 * Name of the parameter that defines the maximum number of objects (per
	 * target container) that can be borrowed from the pool at one time.
	 */
	public static final String PROP_NAME_MAX_ACTIVE = "transporter.nio.client.pool.max";
	
	/**
	 * The default minimum amount of time (30 min) that an NIO
	 * connection may sit idle in the pool before it is eligible for eviction
	 * due to idle time.
	 */
	public static final String DEFAULT_MIN_IDLE_TIME = Long.toString(30*60*1000);

	/**
	 * Name of the parameter that defines the minimum amount of time (in
	 * milli-second) that an NIO connection may sit idle in the pool before it
	 * is eligible for eviction due to idle time.
	 */
	public static final String PROP_NAME_MIN_IDLE_TIME = "transporter.nio.client.pool.min-idle-time";
	
	/**
	 * The default time (10 min) that the eviction thread should sleep before "runs" of
	 * examining idle objects.
	 */
	public static final String DEFAULT_EVICT_RUN_TIME = Long.toString(10*60*1000);

	/**
	 * Name of the parameter that defines how long the eviction thread should
	 * sleep before "runs" of examining idle objects. No eviction thread will be
	 * launched if this parameter has a non-positive value.
	 */
	public static final String PROP_NAME_EVICT_RUN_TIME = "transporter.nio.client.pool.evict-run-time";

}
