/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2009 OW2, http://www.ow2.org/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: $
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.extensions.transporter.nio.server;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.channels.SocketChannel;

import org.objectweb.petals.util.LoggingUtil;
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.api.Logger;
import org.ow2.petals.extensions.transporter.nio.selector.PipedDeserializer;
import org.ow2.petals.extensions.transporter.nio.util.stream.object.MessageExchangeInputStream;
import org.ow2.petals.extensions.transporter.nio.util.stream.queue.QueueInputStream;
import org.ow2.petals.extensions.transporter.nio.util.stream.queue.QueueOutputStream;


public final class PipedDeserializerImpl implements PipedDeserializer {
	
	private final Logger logger;
	private final LoggingUtil log;
	private final OutputStream outputStream;
	private InputStream inputStream;
	private MessageExchangeInputStream objectsStream;
	private Object objectStreamLock = new Object();
	private final SocketChannel socketChannel;
	private final NioReceiver messageReceiver;
	
	public PipedDeserializerImpl(final SocketChannel socketChannel,
			final NioReceiver messageReceiver, final Logger logger,
			final LoggingUtil log) throws IOException {
		this.logger = logger;
		this.log = log;
		// We can't use the following stream:
		// - Circular byte buffer piped stream from Ostermiller because they
		// seem to be not thread-safe,
		// - Standard piped streams because they need to be connected before
		// writing/reading and writes are blocking.
		final QueueOutputStream queueOutputStream = new QueueOutputStream();
		this.outputStream = queueOutputStream;
		this.inputStream = new QueueInputStream(queueOutputStream);
		this.socketChannel = socketChannel;
		this.messageReceiver = messageReceiver;
	}
	
	public final void connectStreams() {
		
	}
	
	public final OutputStream getOutputStream() {
		return this.outputStream;
	}
	
	public final void run() {
        
    	try {
    		
			if (this.logger.isLoggable(BasicLevel.DEBUG)) {
    			this.log.debug("A read occurs on socket " + this.socketChannel.socket().toString());
    		}
    		
			final Object obj;
			synchronized (this.objectStreamLock) {
				if (this.objectsStream == null) {
					this.objectsStream = new MessageExchangeInputStream(this.inputStream);
				}

                // Don't forget to received the flag 'begining of message
                // exchange' to synchronize the message exchange input stream on
                // the server side.
                this.objectsStream.beginningMessageExchange();
                obj = this.objectsStream.readUnshared();
	            
			}
				
			if (this.logger.isLoggable(BasicLevel.DEBUG)) {
				this.log.debug("Received object: " + obj.toString());
			}
			
			this.messageReceiver.onMessage(obj);

			
		} catch (final IOException e) {
			this.log
					.warning("An error occurs during deserialization: ("
							+ e.getMessage()
							+ "). Data are discarded.", e);
		} catch (final ClassNotFoundException e) {
			this.log.error(
					"An error occurs during deserialization: "
							+ e.getMessage()
							+ "). Data are discarded.", e);
		} 
    }

}
