package org.ow2.petals.extensions.transporter.nio.util.stream.object;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;

/**
 * <p>
 * Because of a header, an ObjectOutputStream instance must be used always whith
 * the same ObjectInptStream instance. So we can't use a pool of
 * ObjectOutputStream with a pool of ObjectInputStream because of interleaving
 * risk.
 * </p>
 * <p>
 * A solution is to (re-)write/(re-)read the header at begining of each message
 * exchange write. As the header is already write/read by constructor, it is not
 * write/read when writing/reading the first message exchange
 * </p>
 * 
 * @author Christophe DENEUX - Capgemini Sud
 * 
 */
public class MessageExchangeInputStream extends ObjectInputStream {

    private boolean isWaitingFirstMsgEx;

    public MessageExchangeInputStream(final InputStream in) throws IOException {
        super(in);
        this.isWaitingFirstMsgEx = true;
    }

    public void beginningMessageExchange() throws IOException {
        if (this.isWaitingFirstMsgEx) {
            // The first message exchange will be read
            this.isWaitingFirstMsgEx = false;
        } else {
            // The message exchange that will be read is not the first one, so
            // we must read the header to be synchronized with the
            // ObjectOutputStream of the client side
            super.readStreamHeader();
        }
    }

}
